Struct
QmiMessageDsdSetApnTypeInput
since: 1.26
Description [src]
struct QmiMessageDsdSetApnTypeInput {
/* No available fields */
}
The QmiMessageDsdSetApnTypeInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.26
Instance methods
qmi_message_dsd_set_apn_type_input_get_apn_type_preference_mask
Get the ‘APN Type Preference Mask’ field from self.
since: 1.26
qmi_message_dsd_set_apn_type_input_ref
Atomically increments the reference count of self by one.
since: 1.26
qmi_message_dsd_set_apn_type_input_set_apn_type
Set the ‘APN Type’ field in the message.
since: 1.26
qmi_message_dsd_set_apn_type_input_set_apn_type_preference_mask
Set the ‘APN Type Preference Mask’ field in the message.
since: 1.26
qmi_message_dsd_set_apn_type_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.26